---
sidebar_label: list
title: data_structures.predefined.list
---

## List Objects

```python
class List(ObjectDS)
```

This class serializes python list

soil.data(my_list) will create a list automatically.

#### unserialize

```python
 | @staticmethod
 | unserialize(json_data, metadata)
```

Deprecated method. It can be removed in a few months.

